wrap_point_func_with_point

Function wrap_point_func_with_point 

pub fn wrap_point_func_with_point(
    f: impl Fn(&mut DVec3) + Copy,
    point: DVec3,
) -> impl Fn(&mut DVec3) + Copy
Apply the function by first transform the points to origin based on a point, then apply the function, then transform the points back.